
Oodi music library management tools
===================================

Oodi is a python library used to managing collections of audio files, transcoding files
between formats and tagging metadata to the files.

This module is a clean rewrite to replace 'soundforest' module I wrote earlier.

Naming Oodi
===========

Helsinki just got a very nice new central library called Oodi. I guess it's quite obvious why.

Installing codecs
-----------------

MacOS with homebrew:

    brew install -y flac lame opus-tools wavpack vorbis-tools vorbisgain
